Release notes
#############

This document contains the release notes for the ``ansys-tools-common``
project.

.. vale off

.. towncrier release notes start

`0.4.0 <https://github.com/ansys/ansys-tools-common/releases/tag/v0.4.0>`_ - December 10, 2025
==============================================================================================

.. tab-set::


  .. tab-item:: Added

    .. list-table::
        :header-rows: 0
        :widths: auto

        * - Launcher: implement gRPC transport option handling
          - `#116 <https://github.com/ansys/ansys-tools-common/pull/116>`_


  .. tab-item:: Miscellaneous

    .. list-table::
        :header-rows: 0
        :widths: auto

        * - Chore: update CHANGELOG for v0.3.1
          - `#119 <https://github.com/ansys/ansys-tools-common/pull/119>`_

        * - Docs: Update \`\`CONTRIBUTORS.md\`\` with the latest contributors
          - `#121 <https://github.com/ansys/ansys-tools-common/pull/121>`_, `#125 <https://github.com/ansys/ansys-tools-common/pull/125>`_

        * - Chore: Update missing or outdated files
          - `#122 <https://github.com/ansys/ansys-tools-common/pull/122>`_

        * - [pre-commit.ci] pre-commit autoupdate
          - `#124 <https://github.com/ansys/ansys-tools-common/pull/124>`_, `#128 <https://github.com/ansys/ansys-tools-common/pull/128>`_

        * - Ci: bump actions/checkout from 6.0.0 to 6.0.1
          - `#126 <https://github.com/ansys/ansys-tools-common/pull/126>`_

        * - Build: bump sphinx-gallery from 0.19.0 to 0.20.0
          - `#127 <https://github.com/ansys/ansys-tools-common/pull/127>`_

        * - Ci: bump ansys/actions from 10.1.5 to 10.2.2
          - `#129 <https://github.com/ansys/ansys-tools-common/pull/129>`_

        * - Build: bump sphinx-click from 6.1.0 to 6.2.0
          - `#130 <https://github.com/ansys/ansys-tools-common/pull/130>`_


  .. tab-item:: Documentation

    .. list-table::
        :header-rows: 0
        :widths: auto

        * - Fix: Local launcher fixes
          - `#118 <https://github.com/ansys/ansys-tools-common/pull/118>`_


`0.3.1 <https://github.com/ansys/ansys-tools-common/releases/tag/v0.3.1>`_ - November 27, 2025
==============================================================================================

.. tab-set::


  .. tab-item:: Miscellaneous

    .. list-table::
        :header-rows: 0
        :widths: auto

        * - Feat: bump dev version
          - `#111 <https://github.com/ansys/ansys-tools-common/pull/111>`_

        * - Chore: update CHANGELOG for v0.3.0
          - `#112 <https://github.com/ansys/ansys-tools-common/pull/112>`_

        * - Ci: doc deploy dev missing
          - `#113 <https://github.com/ansys/ansys-tools-common/pull/113>`_

        * - Feat: add fullpath to set UDS sock filename
          - `#114 <https://github.com/ansys/ansys-tools-common/pull/114>`_

        * - Ci: bump actions/checkout from 5.0.1 to 6.0.0
          - `#115 <https://github.com/ansys/ansys-tools-common/pull/115>`_

        * - Ci: bump astral-sh/setup-uv from 7.1.3 to 7.1.4
          - `#117 <https://github.com/ansys/ansys-tools-common/pull/117>`_


`0.3.0 <https://github.com/ansys/ansys-tools-common/releases/tag/v0.3.0>`_ - November 25, 2025
==============================================================================================

.. tab-set::


  .. tab-item:: Dependencies

    .. list-table::
        :header-rows: 0
        :widths: auto

        * - Ci: bump ansys/actions from 10.1.4 to 10.1.5
          - `#92 <https://github.com/ansys/ansys-tools-common/pull/92>`_

        * - Build: bump pyfakefs from 5.10.1 to 5.10.2
          - `#95 <https://github.com/ansys/ansys-tools-common/pull/95>`_

        * - Build: bump pytest from 9.0.0 to 9.0.1
          - `#102 <https://github.com/ansys/ansys-tools-common/pull/102>`_


  .. tab-item:: Miscellaneous

    .. list-table::
        :header-rows: 0
        :widths: auto

        * - Chore: update CHANGELOG for v0.2.1
          - `#77 <https://github.com/ansys/ansys-tools-common/pull/77>`_

        * - Ci: make changelog stage as required for releasing and avoid running old workflows
          - `#78 <https://github.com/ansys/ansys-tools-common/pull/78>`_

        * - Ci: bump astral-sh/setup-uv from 7.0.0 to 7.1.2
          - `#79 <https://github.com/ansys/ansys-tools-common/pull/79>`_

        * - Build: bump pyfakefs from 5.10.0 to 5.10.1
          - `#80 <https://github.com/ansys/ansys-tools-common/pull/80>`_

        * - [pre-commit.ci] pre-commit autoupdate
          - `#82 <https://github.com/ansys/ansys-tools-common/pull/82>`_, `#97 <https://github.com/ansys/ansys-tools-common/pull/97>`_, `#101 <https://github.com/ansys/ansys-tools-common/pull/101>`_, `#109 <https://github.com/ansys/ansys-tools-common/pull/109>`_

        * - Build: bump hypothesis from 6.142.4 to 6.142.5
          - `#91 <https://github.com/ansys/ansys-tools-common/pull/91>`_

        * - Build: bump hypothesis from 6.142.5 to 6.143.0
          - `#93 <https://github.com/ansys/ansys-tools-common/pull/93>`_

        * - Docs: Update \`\`CONTRIBUTORS.md\`\` with the latest contributors
          - `#94 <https://github.com/ansys/ansys-tools-common/pull/94>`_

        * - Build: bump hypothesis from 6.143.0 to 6.146.0
          - `#98 <https://github.com/ansys/ansys-tools-common/pull/98>`_

        * - Build: bump hypothesis from 6.146.0 to 6.147.0
          - `#99 <https://github.com/ansys/ansys-tools-common/pull/99>`_

        * - Build: bump pytest from 8.4.2 to 9.0.0
          - `#100 <https://github.com/ansys/ansys-tools-common/pull/100>`_

        * - Ci: bump astral-sh/setup-uv from 7.1.2 to 7.1.3
          - `#103 <https://github.com/ansys/ansys-tools-common/pull/103>`_

        * - Ci: bump actions/checkout from 5.0.0 to 5.0.1
          - `#104 <https://github.com/ansys/ansys-tools-common/pull/104>`_

        * - Build: bump hypothesis from 6.147.0 to 6.148.0
          - `#105 <https://github.com/ansys/ansys-tools-common/pull/105>`_

        * - Feat: adding cyberchannel module
          - `#107 <https://github.com/ansys/ansys-tools-common/pull/107>`_


`0.2.1 <https://github.com/ansys/ansys-tools-common/releases/tag/v0.2.1>`_ - October 31, 2025
=============================================================================================

.. tab-set::


  .. tab-item:: Miscellaneous

    .. list-table::
        :header-rows: 0
        :widths: auto

        * - Chore: update CHANGELOG for v0.2.0
          - `#76 <https://github.com/ansys/ansys-tools-common/pull/76>`_


`0.2.0 <https://github.com/ansys/ansys-tools-common/releases/tag/v0.2.0>`_ - October 31, 2025
=============================================================================================

.. tab-set::


  .. tab-item:: Added

    .. list-table::
        :header-rows: 0
        :widths: auto

        * - Provide logger formatter separately
          - `#37 <https://github.com/ansys/ansys-tools-common/pull/37>`_

        * - Feat: technical review
          - `#39 <https://github.com/ansys/ansys-tools-common/pull/39>`_


  .. tab-item:: Dependencies

    .. list-table::
        :header-rows: 0
        :widths: auto

        * - Ci: bump actions/download-artifact from 4.3.0 to 5.0.0
          - `#54 <https://github.com/ansys/ansys-tools-common/pull/54>`_

        * - Build: bump pytest-cov from 6.1.1 to 7.0.0
          - `#55 <https://github.com/ansys/ansys-tools-common/pull/55>`_

        * - Build: bump sphinx-click from 4.4.0 to 6.1.0
          - `#59 <https://github.com/ansys/ansys-tools-common/pull/59>`_

        * - Build: bump hypothesis from 6.135.10 to 6.140.3
          - `#60 <https://github.com/ansys/ansys-tools-common/pull/60>`_

        * - Build: bump hypothesis from 6.142.1 to 6.142.2
          - `#69 <https://github.com/ansys/ansys-tools-common/pull/69>`_


  .. tab-item:: Miscellaneous

    .. list-table::
        :header-rows: 0
        :widths: auto

        * - Ci: bump peter-evans/create-or-update-comment from 4.0.0 to 5.0.0
          - `#47 <https://github.com/ansys/ansys-tools-common/pull/47>`_

        * - Ci: bump actions/labeler from 5.0.0 to 6.0.1
          - `#48 <https://github.com/ansys/ansys-tools-common/pull/48>`_

        * - Build: bump pyfakefs from 5.8.0 to 5.9.3
          - `#49 <https://github.com/ansys/ansys-tools-common/pull/49>`_

        * - Ci: bump actions/checkout from 4.2.2 to 5.0.0
          - `#50 <https://github.com/ansys/ansys-tools-common/pull/50>`_

        * - Build: bump pytest from 8.4.0 to 8.4.2
          - `#51 <https://github.com/ansys/ansys-tools-common/pull/51>`_

        * - Chore: grouping grpc dependencies in same dependabot bump
          - `#57 <https://github.com/ansys/ansys-tools-common/pull/57>`_

        * - Maint: Add Dependabot automerge action
          - `#61 <https://github.com/ansys/ansys-tools-common/pull/61>`_

        * - Maint: Add CI bot to CODEOWNERS
          - `#63 <https://github.com/ansys/ansys-tools-common/pull/63>`_

        * - Build: bump pyfakefs from 5.9.3 to 5.10.0
          - `#64 <https://github.com/ansys/ansys-tools-common/pull/64>`_

        * - Build: bump hypothesis from 6.140.3 to 6.140.4
          - `#65 <https://github.com/ansys/ansys-tools-common/pull/65>`_

        * - Build: bump hypothesis from 6.140.4 to 6.141.1
          - `#66 <https://github.com/ansys/ansys-tools-common/pull/66>`_

        * - Build: bump hypothesis from 6.141.1 to 6.142.1
          - `#67 <https://github.com/ansys/ansys-tools-common/pull/67>`_

        * - Build: bump the grpc-deps group with 2 updates
          - `#68 <https://github.com/ansys/ansys-tools-common/pull/68>`_

        * - Build: bump hypothesis from 6.142.2 to 6.142.3
          - `#71 <https://github.com/ansys/ansys-tools-common/pull/71>`_

        * - Ci: bump actions/download-artifact from 5.0.0 to 6.0.0
          - `#72 <https://github.com/ansys/ansys-tools-common/pull/72>`_

        * - Build: bump hypothesis from 6.142.3 to 6.142.4
          - `#73 <https://github.com/ansys/ansys-tools-common/pull/73>`_

        * - Fix: Prepare for public release
          - `#74 <https://github.com/ansys/ansys-tools-common/pull/74>`_


  .. tab-item:: Maintenance

    .. list-table::
        :header-rows: 0
        :widths: auto

        * - Update CHANGELOG for v0.1.0
          - `#36 <https://github.com/ansys/ansys-tools-common/pull/36>`_

        * - Add \`\`ansys/actions/check-actions-security\`\` action and related fixes
          - `#41 <https://github.com/ansys/ansys-tools-common/pull/41>`_


.. vale on
